@@ -3,9 +3,6 @@
 # Univention Management Console
 #  Univention Directory Manager Module
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2019-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -27,15 +24,16 @@ from tornado.httpserver import HTTPServer
 from tornado.netutil import bind_sockets, bind_unix_socket
 
 from univention.admin.rest.shared_memory import shared_memory
-from univention.admin.rest.utils import init_request_id_logging
+from univention.admin.rest.utils import init_request_context_logging
 from univention.config_registry import ucr
 from univention.lib.i18n import Locale, Translation
+from univention.logging import Structured
 # IMPORTANT NOTICE: we must import as few modules as possible, so that univention.admin is not yet imported
 # because importing the UDM handlers would cause that the gettext translation gets applied before we set a locale
 from univention.management.console.log import log_init, log_reopen
 
 
-log = logging.getLogger('ADMIN')
+log = Structured(logging.getLogger('ADMIN'))
 
 
 try:
@@ -54,7 +52,7 @@ class Server:
         self.child_id = None
         setproctitle(proctitle + '   # server')
         # locale must be set before importing UDM!
-        log_init('/dev/stdout', args.debug, args.processes != 1)
+        log_init('/dev/stdout', args.debug, args.processes != 1, use_structured_logging=ucr.is_true('directory/manager/rest/debug/structured-logging'))
         language = str(Locale(args.language))
         locale.setlocale(locale.LC_MESSAGES, language)
         os.umask(0o077)  # FIXME: should probably be changed, this is what UMC sets
@@ -67,11 +65,10 @@ class Server:
         os.environ['LANG'] = language
 
         # tornado logging
-        channel = logging.StreamHandler()
-        channel.setFormatter(tornado.log.LogFormatter(fmt='%(color)s%(asctime)s  %(levelname)10s      (%(process)9d) :%(end_color)s %(message)s', datefmt='%d.%m.%y %H:%M:%S'))
-        logger = logging.getLogger()
-        logger.setLevel(logging.INFO)
-        logger.addHandler(channel)
+        import univention.logging
+        univention.logging.extendLogger('tornado', univention_debug_category='NETWORK')
+        logger = logging.getLogger('tornado')
+        logger.set_ud_level(ucr.get_int('directory/manager/rest/tornado-debug/level', 3))
 
         # start sharing memory (before fork, before first usage, after import)
         shared_memory.start()
@@ -100,7 +97,7 @@ class Server:
             try:
                 child_id = tornado.process.fork_processes(args.processes, 0)
             except RuntimeError as exc:  # tornados way to exit from multiprocessing on failures
-                log.debug('Stopped process: %s', exc)
+                log.debug('Stopped process.', error=exc)
                 self.signal_handler_stop(None, signal.SIGTERM, None)
             else:
                 self.start_child(child_id)
@@ -111,13 +108,15 @@ class Server:
     def start_child(self, child_id):
         setproctitle(proctitle + f'   # child {child_id}')
         self.child_id = child_id
-        log.debug('Started child %s', self.child_id)
+        log.debug('Started child.', child=self.child_id)
         shared_memory.children[self.child_id] = os.getpid()
         self.run_server(self.socks)
 
     def run_server(self, socks):
-        from univention.admin.rest.module import Application, request_id_context
-        application = Application(serve_traceback=ucr.is_true('directory/manager/rest/show-tracebacks', True))
+        from univention.admin.rest.module import Application, request_context
+        application = Application(
+            serve_traceback=ucr.is_true('directory/manager/rest/show-tracebacks', True),
+        )
 
         server = HTTPServer(application)
         server.add_sockets(socks)
@@ -127,7 +126,7 @@ class Server:
         signal.signal(signal.SIGINT, partial(self.signal_handler_stop, server))
         signal.signal(signal.SIGHUP, partial(self.signal_handler_reload, application))
 
-        init_request_id_logging(request_id_context)
+        init_request_context_logging(request_context)
 
         try:
             tornado.ioloop.IOLoop.current().start()
@@ -142,7 +141,7 @@ class Server:
                 children_pids = list(shared_memory.children.values())
             except Exception:  # multiprocessing failure
                 children_pids = []
-            log.debug('stopping children: %r', children_pids)
+            log.debug('Stopping children.', children=children_pids)
             for pid in children_pids:
                 self.safe_kill(pid, sig)
 
@@ -155,7 +154,7 @@ class Server:
 
         def stop_loop(deadline):
             now = time.time()
-            if now < deadline:  # and (io_loop.callbacks or io_loop.timeouts):  # FIXME: neither _UnixSelectorEventLoop nor AsyncIOMainLoop have callbacks
+            if now < deadline:
                 io_loop.add_timeout(now + 1, stop_loop, deadline)
             else:
                 loop.stop()
@@ -187,7 +186,7 @@ class Server:
         try:
             os.kill(pid, signo)
         except OSError as exc:
-            log.error('Could not kill(%s) %s: %s', signo, pid, exc)
+            log.error('Could not kill children', signo=signo, pid=pid, error=exc)
         else:
             os.waitpid(pid, os.WNOHANG)
 
